# File Structure

-- models

    -- frozen_east_text_detection.pb
   
-- OCR_Printed_Text.py

-- __init__.py

-- bhasha_codes.py

-- downloader.py

-- natural_photo_se_text.py

-- photo_se_nikali_awaj.py

-- photo_se_text.py

-- text_bol_uthega.py

-- downloader.py

